import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;
import java.io.*;
import javax.swing.*;
import javax.imageio.*;

/**
 * パネルクラス
 */
public class MGPanel extends JPanel {

	/** マウスアダプタ */
	private		MGMouseAdapter		mgma		= null;

	/** ピコピコハンマー座標 */
	private		int					px			= 0;
	/** ピコピコハンマー座標 */
	private		int					py			= 0;

	/** もぐら座標 */
	private		int					mx			= 350;
	/** もぐら座標 */
	private		int					my			= 200;

	/** ピコピコハンマー */
	private		BufferedImage[]		imagePHs	= null;
	/** ピコピコハンマー状態 */
	private		int					ph			= 0;

	/** もぐら */
	private		BufferedImage[]		imageMs		= null;
	/** もぐら状態 */
	private		int					m			= 0;

	/**
	 * コンストラクタ
	 */
	public MGPanel() {

		// スーパークラスを呼び出す
		super();

		try{

			// パネルサイズ
			super.setPreferredSize(new Dimension(800, 600));
			// レイアウト設定
			super.setLayout(null);

			// マウスアダプタを生成
			mgma = new MGMouseAdapter();
			// パネルにマウスリスナーを追加する
			super.addMouseListener(mgma);
			super.addMouseMotionListener(mgma);

			// ピコピコハンマーを読み込む
			imagePHs = new BufferedImage[2];
			InputStream isPH00 = this.getClass().getResourceAsStream("PH00.gif");
			imagePHs[0] = ImageIO.read(isPH00);
			isPH00.close();

			InputStream isPH01 = this.getClass().getResourceAsStream("PH01.gif");
			imagePHs[1] = ImageIO.read(isPH01);
			isPH01.close();

			// もぐらを読み込む
			imageMs = new BufferedImage[2];
			InputStream isM00 = this.getClass().getResourceAsStream("M00.gif");
			imageMs[0] = ImageIO.read(isM00);
			isM00.close();

			InputStream isM01 = this.getClass().getResourceAsStream("M01.gif");
			imageMs[1] = ImageIO.read(isM01);
			isM01.close();

		}catch(Exception ex){
			ex.printStackTrace();
			JOptionPane.showMessageDialog(this, "ERROR : " + ex.toString());
		}

	} // end MGPanel

	/**
	 * 描画メソッド.
	 * <pre>
	 * ペイントする必要があるときにこのメソッドを呼び出されます。
	 * </pre>
	 */
	public void paint(Graphics g){

		// 画面を塗りつぶす
		g.setColor(Color.black);
		g.fillRect(0, 0, 800, 600);

		// もぐらを描画する
		g.drawImage(imageMs[m], mx, my, 100, 100, this);

		// ピコピコハンマーを描画する
		g.drawImage(imagePHs[ph], px, py, 100, 88, this);

	} // end paint

	/**
	 * マウスアダプタ
	 */
	private class MGMouseAdapter extends MouseAdapter {

		/**
		 * マウスが押された時に呼ばれます
		 */
		public void mousePressed(MouseEvent me){

			// ピコピコハンマー叩く
			ph = 1;
			// 場所を記憶する
			px = me.getX() - 100;
			py = me.getY() - 100;

			// もぐらとの当たり判定
			if(px > mx - 50 && px < mx + 90 && py > my - 70 && py < my + 60){
				m = 1;
			}else{
				m = 0;
			}

			// 描画する
			repaint();

		} //  end mousePressed

		/**
		 * マウスが離された時に呼ばれます
		 */
		public void mouseReleased(MouseEvent me){

			// ピコピコハンマーを上げる
			ph = 0;
			// 場所を記憶する
			px = me.getX() - 100;
			py = me.getY() - 100;

			// もぐらとの当たり判定
			m = 0;

			// 描画する
			repaint();

		} //  end mouseReleased

		/**
		 * マウスが移動された時に呼ばれます
		 */
		public void mouseMoved(MouseEvent me){

			// 場所を記憶する
			px = me.getX() - 100;
			py = me.getY() - 100;
			// 描画する
			repaint();

		} //  end mouseMoved

		/**
		 * マウスがドラッグされた時に呼ばれます
		 */
		public void mouseDragged(MouseEvent me){

			// 場所を記憶する
			px = me.getX() - 100;
			py = me.getY() - 100;
			// 描画する
			repaint();

		} //  end mouseDragged

	} // end MGMouseAdapter

}
